pub struct MetricsArchiveInternalClient { /* private fields */ }Expand description
A service client for the internal metrics archive API. It’s only for Coralogix internal use.
Implementations
Sourceimpl MetricsArchiveInternalClient
impl MetricsArchiveInternalClient
Sourcepub fn new(region: CoralogixRegion, auth_context: AuthContext) -> Result<Self>
pub fn new(region: CoralogixRegion, auth_context: AuthContext) -> Result<Self>
Creates a new client for the internal Metrics Archive API.
Arguments
auth_context- The to use for authentication.region- The region to connect to.
Sourcepub async fn get_tenant_config(
&self,
tenant_id: u32,
) -> Result<GetTenantConfigResponse>
pub async fn get_tenant_config( &self, tenant_id: u32, ) -> Result<GetTenantConfigResponse>
Gets the tenant configuration.
Arguments
tenant_id- The ID of the tenant to get the configuration for.
Sourcepub async fn list_tenant_configs(&self) -> Result<ListTenantConfigsResponse>
pub async fn list_tenant_configs(&self) -> Result<ListTenantConfigsResponse>
Lists the tenant configurations.
Sourcepub async fn list_hot_store_configs(
&self,
) -> Result<ListHotStoreConfigsResponse>
pub async fn list_hot_store_configs( &self, ) -> Result<ListHotStoreConfigsResponse>
Lists the hot store configurations.
Sourcepub async fn migrate_tenant(&self, tenant_id: u32) -> Result<()>
pub async fn migrate_tenant(&self, tenant_id: u32) -> Result<()>