pub struct QuerySeriesVisibility {
pub query: Option<SeriesVisibilityQueryMatcher>,
pub threshold: Option<SeriesVisibilityThresholdMatcher>,
pub visibility: i32,
pub series_names: Vec<String>,
}Fields
query: Option<SeriesVisibilityQueryMatcher>threshold: Option<SeriesVisibilityThresholdMatcher>visibility: i32series_names: Vec<String>Implementations
Sourceimpl QuerySeriesVisibility
impl QuerySeriesVisibility
Sourcepub fn visibility(&self) -> SeriesVisibilityMode
pub fn visibility(&self) -> SeriesVisibilityMode
Returns the enum value of visibility, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility(&mut self, value: SeriesVisibilityMode)
pub fn set_visibility(&mut self, value: SeriesVisibilityMode)
Sets visibility to the provided enum value.