pub struct SeriesVisibilityQueryMatcher {
pub query_id: Option<String>,
}Fields
query_id: Option<String>Trait Implementations
Sourceimpl Clone for SeriesVisibilityQueryMatcher
impl Clone for SeriesVisibilityQueryMatcher
Sourcefn clone(&self) -> SeriesVisibilityQueryMatcher
fn clone(&self) -> SeriesVisibilityQueryMatcher
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SeriesVisibilityQueryMatcher
impl Debug for SeriesVisibilityQueryMatcher
Sourceimpl Default for SeriesVisibilityQueryMatcher
impl Default for SeriesVisibilityQueryMatcher
Sourcefn default() -> SeriesVisibilityQueryMatcher
fn default() -> SeriesVisibilityQueryMatcher
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SeriesVisibilityQueryMatcher
impl<'de> Deserialize<'de> for SeriesVisibilityQueryMatcher
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SeriesVisibilityQueryMatcher, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SeriesVisibilityQueryMatcher, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for SeriesVisibilityQueryMatcher
impl Message for SeriesVisibilityQueryMatcher
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SeriesVisibilityQueryMatcher
impl PartialEq for SeriesVisibilityQueryMatcher
Sourcefn eq(&self, other: &SeriesVisibilityQueryMatcher) -> bool
fn eq(&self, other: &SeriesVisibilityQueryMatcher) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SeriesVisibilityQueryMatcher
impl Serialize for SeriesVisibilityQueryMatcher
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SeriesVisibilityQueryMatcher