pub struct VerticalBarsMulti {Show 17 fields
pub category_fields: Vec<ObservationField>,
pub query_field_settings: Vec<QueryFieldSettings>,
pub max_bars_per_chart: Option<i32>,
pub scale_type: i32,
pub colors_by: Option<ColorsBy>,
pub color_scheme: Option<String>,
pub hash_colors: Option<bool>,
pub unit: i32,
pub custom_unit: Option<String>,
pub bar_value_display: i32,
pub decimal_precision: Option<i32>,
pub allow_abbreviation: Option<bool>,
pub y_axis_min: Option<f32>,
pub y_axis_max: Option<f32>,
pub legend: Option<Legend>,
pub group_name_template: Option<String>,
pub sort_order: Option<SortOrder>,
}Fields
category_fields: Vec<ObservationField>query_field_settings: Vec<QueryFieldSettings>max_bars_per_chart: Option<i32>scale_type: i32colors_by: Option<ColorsBy>color_scheme: Option<String>hash_colors: Option<bool>unit: i32custom_unit: Option<String>bar_value_display: i32decimal_precision: Option<i32>allow_abbreviation: Option<bool>y_axis_min: Option<f32>y_axis_max: Option<f32>legend: Option<Legend>group_name_template: Option<String>sort_order: Option<SortOrder>Implementations
Sourceimpl VerticalBarsMulti
impl VerticalBarsMulti
Sourcepub fn scale_type(&self) -> ScaleType
pub fn scale_type(&self) -> ScaleType
Returns the enum value of scale_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_scale_type(&mut self, value: ScaleType)
pub fn set_scale_type(&mut self, value: ScaleType)
Sets scale_type to the provided enum value.
Sourcepub fn unit(&self) -> Unit
pub fn unit(&self) -> Unit
Returns the enum value of unit, or the default if the field is set to an invalid enum value.
Sourcepub fn bar_value_display(&self) -> BarValueDisplay
pub fn bar_value_display(&self) -> BarValueDisplay
Returns the enum value of bar_value_display, or the default if the field is set to an invalid enum value.
Sourcepub fn set_bar_value_display(&mut self, value: BarValueDisplay)
pub fn set_bar_value_display(&mut self, value: BarValueDisplay)
Sets bar_value_display to the provided enum value.