pub struct HorizontalBarsMulti {Show 18 fields
pub category_fields: Vec<ObservationField>,
pub query_field_settings: Vec<QueryFieldSettings>,
pub max_bars_per_chart: Option<i32>,
pub scale_type: i32,
pub colors_by: Option<ColorsBy>,
pub color_scheme: Option<String>,
pub hash_colors: Option<bool>,
pub unit: i32,
pub custom_unit: Option<String>,
pub display_on_bar: Option<bool>,
pub decimal_precision: Option<i32>,
pub allow_abbreviation: Option<bool>,
pub y_axis_min: Option<f32>,
pub y_axis_max: Option<f32>,
pub legend: Option<Legend>,
pub group_name_template: Option<String>,
pub y_axis_view_by: i32,
pub sort_order: Option<SortOrder>,
}Fields
category_fields: Vec<ObservationField>query_field_settings: Vec<QueryFieldSettings>max_bars_per_chart: Option<i32>scale_type: i32colors_by: Option<ColorsBy>color_scheme: Option<String>hash_colors: Option<bool>unit: i32custom_unit: Option<String>display_on_bar: Option<bool>decimal_precision: Option<i32>allow_abbreviation: Option<bool>y_axis_min: Option<f32>y_axis_max: Option<f32>legend: Option<Legend>group_name_template: Option<String>y_axis_view_by: i32sort_order: Option<SortOrder>Implementations
Sourceimpl HorizontalBarsMulti
impl HorizontalBarsMulti
Sourcepub fn scale_type(&self) -> ScaleType
pub fn scale_type(&self) -> ScaleType
Returns the enum value of scale_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_scale_type(&mut self, value: ScaleType)
pub fn set_scale_type(&mut self, value: ScaleType)
Sets scale_type to the provided enum value.
Sourcepub fn unit(&self) -> Unit
pub fn unit(&self) -> Unit
Returns the enum value of unit, or the default if the field is set to an invalid enum value.
Sourcepub fn y_axis_view_by(&self) -> YAxisViewBy
pub fn y_axis_view_by(&self) -> YAxisViewBy
Returns the enum value of y_axis_view_by, or the default if the field is set to an invalid enum value.
Sourcepub fn set_y_axis_view_by(&mut self, value: YAxisViewBy)
pub fn set_y_axis_view_by(&mut self, value: YAxisViewBy)
Sets y_axis_view_by to the provided enum value.