pub struct DatasetClient { /* private fields */ }๐Deprecated: This API will change significantly under a new name.
The Custom Enrichments API client. Read more at https://coralogix.com/docs/custom-enrichment-api/
Implementations
Sourceimpl DatasetClient
impl DatasetClient
Sourcepub fn new(auth_context: AuthContext, region: CoralogixRegion) -> Result<Self>
pub fn new(auth_context: AuthContext, region: CoralogixRegion) -> Result<Self>
Creates a new client for the Custom Enrichments API.
Arguments
auth_context- TheAuthContextto use for authentication.region- TheCoralogixRegionto connect to.
Sourcepub async fn create(
&self,
name: String,
description: Option<String>,
data: Vec<u8>,
) -> Result<CreateCustomEnrichmentResponse>
pub async fn create( &self, name: String, description: Option<String>, data: Vec<u8>, ) -> Result<CreateCustomEnrichmentResponse>
Creates a new dataset.
Arguments
name- The name of the Custom Enrichment.description- The description of the Custom Enrichment.data- The data of the Custom Enrichment.
Sourcepub async fn replace(
&self,
id: u32,
name: String,
description: Option<String>,
data: Vec<u8>,
) -> Result<UpdateCustomEnrichmentResponse>
pub async fn replace( &self, id: u32, name: String, description: Option<String>, data: Vec<u8>, ) -> Result<UpdateCustomEnrichmentResponse>
Replaces the existing dataset identified by its id.
Arguments
id- The id of the Custom Enrichment.name- The name of the Custom Enrichment.description- The description of the Custom Enrichment.data- The data of the Custom Enrichment.
Note that the existing dataset will be replaced with a new version of the data.
Sourcepub async fn delete(
&self,
custom_enrichment_id: u32,
) -> Result<DeleteCustomEnrichmentResponse>
pub async fn delete( &self, custom_enrichment_id: u32, ) -> Result<DeleteCustomEnrichmentResponse>
Deletes the dataset identified by its id.
Arguments
custom_enrichment_id- The id of the Custom Enrichment.
Sourcepub async fn get(&self, id: u32) -> Result<GetCustomEnrichmentResponse>
pub async fn get(&self, id: u32) -> Result<GetCustomEnrichmentResponse>
Sourcepub async fn list(&self) -> Result<GetCustomEnrichmentsResponse>
pub async fn list(&self) -> Result<GetCustomEnrichmentsResponse>