pub struct TeamsClient { /* private fields */ }Expand description
The Team API client. Read more at https://coralogix.com/docs/user-team-management/ and https://coralogix.com/docs/user-guides/account-management/payment-and-billing/quota-management/
Implementations
Sourceimpl TeamsClient
impl TeamsClient
Sourcepub fn new(auth_context: AuthContext, region: CoralogixRegion) -> Result<Self>
pub fn new(auth_context: AuthContext, region: CoralogixRegion) -> Result<Self>
Creates a new client for the Teams API.
Arguments
auth_context- TheAuthContextto use for authentication.region- TheCoralogixRegionto connect to.
Sourcepub async fn create(
&self,
team_name: String,
team_admins_email: Vec<String>,
daily_quota: Option<f64>,
) -> Result<CreateTeamInOrgResponse>
pub async fn create( &self, team_name: String, team_admins_email: Vec<String>, daily_quota: Option<f64>, ) -> Result<CreateTeamInOrgResponse>
Creates a new Team in the organization.
Arguments
team_name- The name of the team.team_admins_email- The email addresses of the team admins.daily_quota- The daily quota for the team.
Sourcepub async fn replace(
&self,
team_id: u32,
team_name: Option<String>,
daily_quota: Option<f64>,
) -> Result<UpdateTeamResponse>
pub async fn replace( &self, team_id: u32, team_name: Option<String>, daily_quota: Option<f64>, ) -> Result<UpdateTeamResponse>
Update the Team identified by its id.
Arguments
team_id- The id of the team to replace.team_name- The name of the team.daily_quota- The daily quota for the team.
Sourcepub async fn delete(&self, team_id: u32) -> Result<DeleteTeamResponse>
pub async fn delete(&self, team_id: u32) -> Result<DeleteTeamResponse>
Sourcepub async fn get(&self, team_id: u32) -> Result<GetTeamResponse>
pub async fn get(&self, team_id: u32) -> Result<GetTeamResponse>
Sourcepub async fn get_quota(&self, team_id: u32) -> Result<GetTeamQuotaResponse>
pub async fn get_quota(&self, team_id: u32) -> Result<GetTeamQuotaResponse>
Sourcepub async fn set_daily_quota(
&self,
team_id: u32,
target_daily_quota: f32,
) -> Result<SetDailyQuotaResponse>
pub async fn set_daily_quota( &self, team_id: u32, target_daily_quota: f32, ) -> Result<SetDailyQuotaResponse>
Sets the daily Team quota.
Arguments
team_id- The id of the team to retrieve.target_daily_quota- The new daily quota for the team.
Sourcepub async fn move_quota(
&self,
source_team_id: u32,
destination_team_id: u32,
units_to_move: f64,
) -> Result<MoveQuotaResponse>
pub async fn move_quota( &self, source_team_id: u32, destination_team_id: u32, units_to_move: f64, ) -> Result<MoveQuotaResponse>
Moves the quota units from one team to the other.
Arguments
source_team_id- The id of the team to move the quota from.destination_team_id- The id of the team to move the quota to.units_to_move- The number of units to move.
Sourcepub async fn list(&self) -> Result<ListTeamsResponse>
pub async fn list(&self) -> Result<ListTeamsResponse>